searchData={"items":[{"type":"module","title":"AprsUtils.AprsIs","doc":"A module to connect to an APRS-IS server and listen for packets.\n\nThese functions implement a client for the APRS-IS server. To use this module, you must implement a\nclient module that implements the AprsUtils.AprsIsClient behaviour. The client module will be called\nwhen packets are recieved from the APRS-IS server.","ref":"AprsUtils.AprsIs.html"},{"type":"module","title":"Example - AprsUtils.AprsIs","doc":"defmodule Client do\n      @behaviour AprsUtils.AprsIsClient\n\n      def got_packet(packet, _packet_count) do\n        IO.puts(\"Got packet: #{String.replace_invalid(packet)}\")\n      end\n\n      def got_comment(comment) do\n        IO.puts(\"Got comment: #{String.replace_invalid(comment)}\")\n      end\n\n      def disconnected(reason) do\n        IO.puts(\"Disconnected: #{reason}\")\n      end\n    end\n\n    {:ok, aprs_is_pid} =\n      AprsIs.connect(\n        username: \"my_call_sign\",\n        password: \"my_aprs_is_password\",\n        app_name: \"MyAppName\",\n        app_version: \"0.1\",\n        client_module: Client\n      )\n\nNote to connect to APRS-IS take a look at [Connecting to APRS-IS](http://www.aprs-is.net/Connecting.aspx). Also, please\nfollow the [rules and guidelines](https://www.aprs-is.net/Default.aspx) for using APRS-IS.","ref":"AprsUtils.AprsIs.html#module-example"},{"type":"function","title":"AprsUtils.AprsIs.close/1","doc":"Closes the connection to the APRS-IS server. The `aprs_is_pid` is the pid returned by `connect`. Note that calling this does not\ncause a call to the `disconnected` callback in the client module.","ref":"AprsUtils.AprsIs.html#close/1"},{"type":"function","title":"AprsUtils.AprsIs.connect/1","doc":"Connects to the APRS-IS server and starts listening for packets.\n\n`opts` may contain the following fields:\n\n- :host - The hostname of the APRS-IS server. Defaults to \"rotate.aprs.net\".\n- :port - The port of the APRS-IS server. Defaults to 14580.\n- :username - The username (typically your CALLSIGN) to connect to the APRS-IS server.\n- :password - The password to connect to the APRS-IS server.\n- :app_name - The name of your application.\n- :app_version - The version of your application.\n- :filter - The filter. See the docs [here](https://www.aprs-is.net/javAPRSFilter.aspx) to use for the APRS-IS server. Defaults to `\"t/poimqstunw\"`.\n- :client_module - The module that implements the AprsUtilsIsClient behaviour.\n\nAll of the fields are required except for `:host`, `:port`, and `:filter` which have defaults.\n\nReturns `{:ok, pid}` if the connection is successful. The `pid` is the pid of the listener process that is spawned by a successful call.\n\nReturns `{:error, reason}` if the connection fails. `reason` is a binary describing the error.\n\n> Note that only one connection can be made to the APRS-IS server. It was intended that multiple connections could be made to the APRS-IS server, but this does\n> not work as of this release.","ref":"AprsUtils.AprsIs.html#connect/1"},{"type":"function","title":"AprsUtils.AprsIs.is_connected?/1","doc":"Returns `true` if the APRS-IS server is connected, `false` otherwise. The `aprs_is_pid` is the pid returned by `connect`.","ref":"AprsUtils.AprsIs.html#is_connected?/1"},{"type":"behaviour","title":"AprsUtils.AprsIsClient","doc":"Callbacks for the AprsUtils.AprsIs client module","ref":"AprsUtils.AprsIsClient.html"},{"type":"callback","title":"AprsUtils.AprsIsClient.disconnected/1","doc":"Called when the connection to the APRS-IS server is disconnected. `reason` is a term\ndescribing the reason for the disconnection. The return value is ignored.","ref":"AprsUtils.AprsIsClient.html#c:disconnected/1"},{"type":"callback","title":"AprsUtils.AprsIsClient.got_comment/1","doc":"Called when a comment is recieved from the APRS-IS server. Note that `comment` is\na binary, but not necessarily a valid `String`. The return value is ignored.","ref":"AprsUtils.AprsIsClient.html#c:got_comment/1"},{"type":"callback","title":"AprsUtils.AprsIsClient.got_packet/2","doc":"Called when a packet is recieved from the APRS-IS server. Note that `packet` is\na binary, but not necessarily a valid `String`. `packet_count` is the number of packets\nrecieved since the connection was established. The return value is ignored.","ref":"AprsUtils.AprsIsClient.html#c:got_packet/2"},{"type":"module","title":"AprsUtils.AprsParser","doc":"Module for parsing APRS packets into components.","ref":"AprsUtils.AprsParser.html"},{"type":"module","title":"Philosopy - AprsUtils.AprsParser","doc":"By its own admission, the APRS protocol is complex and shows definate signs of having\na design which evolved and grew during it's development. This module is designed to abstract\nas much of this away as possible. It reveals only the actual information contained in the packet,\nand as little about the protocol as it can. For example, the module will not return any\ninformation about the type of packet, or if the positional information was compressed.\nBasically the structure that is returns contains the information the\npacket contains, and `nil` in the information fields that the packet does not contain.\n\nSee this set of documents for the APRS protocol:\n\n* [APRS 1.0.1 Spec](http://www.aprs.org/doc/APRS101.PDF)\n* [APRS 1.1 Addendum](http://www.aprs.org/aprs11.html)\n* [APRS 1.2 Addendum](http://www.aprs.org/aprs12.html)","ref":"AprsUtils.AprsParser.html#module-philosopy"},{"type":"module","title":"Units - AprsUtils.AprsParser","doc":"For historical reasons, APRS uses a variety of units. This module will convert all units to this\nset of SI units.\n\n* latitude, longitude: degrees (float)\n* distance: meters (float)\n* speed: meters per second (float)\n* temperature: degrees Celsius (float)\n* pressure: pascals (float)\n* humidity: relative percent (float)","ref":"AprsUtils.AprsParser.html#module-units"},{"type":"module","title":"Time handling - AprsUtils.AprsParser","doc":"Some, but not all, APRS packet formats contain timestamps. However all of the formats give only partial time information.\nOne of the most common formats, for example, provides the day, hour, and minutes of transmission. It is the receiver's\nresponsibility to provide the year and month. This can introduce incorrect interpretation of the time, especially if the\ntime between transmission and parsing of the data is long. This module does not attempt to interpret the time, but\nsimply returns the time information that is in the packet. Note that most, but not all, timestamp formats are Zulu Time.","ref":"AprsUtils.AprsParser.html#module-time-handling"},{"type":"module","title":"Caution on binary data - AprsUtils.AprsParser","doc":"Many of the fields described below are returned as binaries taken directly from the APRS packet. These binaries are not\nnecessarily valid UTF-8 strings. In fact, it is common for APRS packets to contain non-printable characters, and non-UTF-8.\nIf you attempt to use these for in an `iolist` for example, make sure you are prepared to handle non-UTF-8 binaries that\nfail `String.valid?/1`.","ref":"AprsUtils.AprsParser.html#module-caution-on-binary-data"},{"type":"module","title":"Unsupported APRS Features - AprsUtils.AprsParser","doc":"This is the set of *Data Type Identifiers* which *are* supported (others will return `{:error, ...}` tuples).\n``[\"!\",  \"=\", \"@\", \"/\", \"'\", \"`\", <<\\x1c>>, <<\\x1d>>, \">\", \":\", \"T\", \";\", \")\", \"$\", \"_\" ]``\n\nThis module does not support the \"!DAO!\" construct in the Mic-E format.\n\nThis module does not recognize the software/device identifiers (APxxxx) in the TO field.","ref":"AprsUtils.AprsParser.html#module-unsupported-aprs-features"},{"type":"function","title":"AprsUtils.AprsParser.parse/1","doc":"Parses an APRS string into components.","ref":"AprsUtils.AprsParser.html#parse/1"},{"type":"function","title":"Args - AprsUtils.AprsParser.parse/1","doc":"- `aprs_packet` - The APRS packet to parse. Note that this is a binary, but is not necessarily a\nvalid String. APRS packets can, and regularly do, contain non-printable characters, and non-UTF-8 sequences.","ref":"AprsUtils.AprsParser.html#parse/1-args"},{"type":"function","title":"Successful Returns - AprsUtils.AprsParser.parse/1","doc":"`{:ok, %AprsUtils.AprsParser{}}`\n\n If an :ok is returned, the APRS packet has been successfully parsed into a struct. The struct contains the\n decoded components of the APRS packet. If the field of the struct is nil, then the packet did not contain\n that information.\n\n Here is how to interpret each field of the struct:\n\n| Field | Description |\n| ----- | ----------- |\n| `:raw` | The same binary passed in to the parse function. |\n| `:to` | A binary containing callsign of the station from which the packet is sent. |\n| `:from` | A binary often containing callsign of the station to which the packet is sent. Or, this can be used to encode other information found in the packet. |\n| `:path` | A list of binaries containing the callsigns of the digipeaters or other gateways that the packet has passed through. |\n| `:timestamp` | A map containting a set of the following fields: `:month`, `:day`, `:hour`, `:minute`, `:second`, and `timezone`. The fields are all integers, except for `:timezone`, which is either `:zulu` or `:local_to_sender`. |\n| `:symbol` | A two byte binary containing the symbol table and symbol represented in the packet. If you want to extract the bytes you can match `< >` |\n| `:position` | A map, see the table below for the fields. |\n| `:course` | A map, see the table below for the fields. |\n| `:antenna` | A map, see the table below for the fields. |\n| `:weather` | A map, see the table below for the fields. |\n| `:telemetry` | A map containing `:sequence_counter`, `:values`, and `:bits`. `:sequence_counter` is an integer used to order telemetry reports. `:values` and `:bits` are lists. The former contains numeric values, and the later is a sequence of either `1` or `0`. |\n| `:message` | Certain APRS packets are meant to be messages to a specific destination. In this case a message map is returned with the following fields: `:addressee`, `:message`, `:message_no` (which may be missing). `:message` is a textual message. `:message_no` is an integer message sequencer. |\n| `:status` | A binary which is the text from a packet containing a status report. Note, this is distinct from a message or a comment. |\n| `:device` | A binary containing the name of the sending device. This implementation is a bit weak in this area. |\n| `:object` | A map which define's an object which has the fields `:name` and `:state`. `:name` is a binary identifier, and `:state` is either `:killed` or `:alive`. |\n| `:item` | An item is just like an object (above) except that semantically it represents an inanimate thing that are occasionally posted on a map (e.g. marathon checkpoints or first-aid posts). |\n| `:raw_gps` | A binary. A packet can contain the raw GPS information in one of the popular GPS device formats, like an NMEA sentence. |\n| `:comment` | A binary comment on the packet. |\n\n\n| Position | |\n| -------- | ----------- |\n| `:latitude` | A tuple in the form `{degrees, precision}` where `degrees` is a float, and `precision` is one of `:hundredth_minute`, `:tenth_minute`, `:minute`, `:tenth_degree`, or `:degree` giving the approximate precision. |\n| `:longitude` | A tuple in the form `{degrees, precision}` where `degrees` is a float, and `precision` is one of `:hundredth_minute`, `:tenth_minute`, `:minute`, `:tenth_degree`, or `:degree` giving the approximate precision. |\n| `:maidenhead` | A string like `IO91SX`. This is given instead of latitude and longitude, but is considered obsolete. |\n| `:altitude` | A floating point number in meters. |\n\n| Course | |\n| ------ | ----------- |\n| `:direction` | A float in degrees. |\n| `:speed` | A float in meters per second. |\n| `:bearing` | A float in degrees. |\n| `:range` | A float in meters. |\n| `:report_quality` | An integer from 0 to 8 with 8 being the best, or `:manual`. |\n| `:bearing_accuracy` | An integer from 1 to 9 with 9 being the best, or `:useless`. See Chapter 7 of the APRS Spec. if you want to understand report quality and bearing accuracy better. |\n\n| Antenna | |\n| ------ | ----------- |\n| `:power` | A float in watts. |\n| `:strength` | An integer in S-points from 0 to 9. |\n| `:height` | A float in meters. |\n| `:directivity` | A float in degrees, or `:omnidirectional`. |\n\n| Weather | |\n| ------ | ----------- |\n| `:temperature` | A float in degrees celsius. |\n| `:wind_speed` | A float in meters per second. |\n| `:wind_direction` | A float in degrees. |\n| `:gust_speed` | A float in meters per second. |\n| `:barometric_pressure` | A float in pascals. |\n| `:humidity` | A float in percent. |\n| `:rainfall_last_hour` | A float in meters. |\n| `:rainfall_last_24_hours` | A float in meters. |\n| `:rainfall_since_midnight` | A float in meters. |\n| `:rain_counts` | A float in counts. |\n| `:luminosity` | A float in watts per square meter. |\n| `:snow_fall` | A float in meters. |\n| `:water_height` | A float in meters. |\n| `:peak_wind_gust` | A float in meters per second. |\n| `:hurricane_winds_radius` | A float in meters. |\n| `:tropical_storm_winds_radius` | A float in meters. |\n| `:gale_force_winds_radius` | A float in meters. |\n| `:software_type` | A binary. Together with `:wx_unit` are meant to describe the weather device reporting. This isn't robustly handled. |\n| `:wx_unit` | A binary. |","ref":"AprsUtils.AprsParser.html#parse/1-successful-returns"},{"type":"function","title":"Error Returns - AprsUtils.AprsParser.parse/1","doc":"`{:error, Map.t()}`\n\n| Field |  |\n| ----- | ----------- |\n| `:raw` | The same binary passed in to the parse function. |\n| `:error` | A binary describing the error. |\n| `:near_character_position` | An integer indicating the position in the binary where the error was detected. |\n\nNote that for many type of errors `:near_character_position` will be nil.","ref":"AprsUtils.AprsParser.html#parse/1-error-returns"},{"type":"extras","title":"AprsUtils","doc":"# AprsUtils \n\nLibrary with two useful (hopefully) modules for APRS developers.\n* `AprsParser`: Module for parsing APRS packets into components.\n* `AprsIs`: Module for connecting to APRS-IS","ref":"readme.html"},{"type":"extras","title":"Short explanation - AprsUtils","doc":"APRS stands for \"Automatic Position Reporting System\". It is a protocol used by\namateur radio operators around the world to track the location of moving objects \nvia packet radio. If you want to take a look at what is being tracked right now\nin your area, visit [here](https://aprs.fi).","ref":"readme.html#short-explanation"},{"type":"extras","title":"References - AprsUtils","doc":"If you want to learn more you can start with the specifications below. Recieving\nall of this data is free and open to anyone. However, you need to be a licensed\nham to inject any data into the network, even into the internet servers, because\nthat data can be broadcast over ham radio frequencies.\n\n#","ref":"readme.html#references"},{"type":"extras","title":"The APRS Spec - AprsUtils","doc":"* [APRS 1.0.1 Spec](http://www.aprs.org/doc/APRS101.PDF)\n* [APRS 1.1 Addendum](http://www.aprs.org/aprs11.html)\n* [APRS 1.2 Addendum](http://www.aprs.org/aprs12.html)\n\n#","ref":"readme.html#the-aprs-spec"},{"type":"extras","title":"The APRS_IS documentation - AprsUtils","doc":"* [APRS-IS](https://www.aprs-is.net/)","ref":"readme.html#the-aprs_is-documentation"},{"type":"extras","title":"Installation - AprsUtils","doc":"Add `aprs_utils` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:aprs_utils, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}